@@ -36,6 +36,7 @@ __author__ = "Dmitry Vasiliev <dima@hlabs.spb.ru>"
 from struct import pack, unpack
 from array import array
 from zlib import decompressobj, compress
+from datetime import datetime
 
 
 class IncompleteData(ValueError):
@@ -215,7 +216,7 @@ def decode_term(string,
         if len(tail) < length:
             raise IncompleteData("incomplete data: %r" % string)
         n = 0
-        for i in array('B', tail[length::-1]):
+        for i in array('B', tail[length-1::-1]):
             n = (n << 8) | i
         if sign:
             n = -n
@@ -253,7 +254,7 @@ def encode_term(term,
                 pack=pack, tuple=tuple, len=len, isinstance=isinstance,
                 list=list, int=int, long=long, array=array, unicode=unicode,
                 Atom=Atom, BitBinary=BitBinary, str=str, float=float, ord=ord,
-                dict=dict, True=True, False=False,
+                dict=dict, datetime=datetime, True=True, False=False,
                 ValueError=ValueError, OverflowError=OverflowError):
     if isinstance(term, tuple):
         arity = len(term)
@@ -343,5 +344,8 @@ def encode_term(term,
         return encode_term(sorted(term.iteritems()))
     elif term is None:
         return pack(">BH", 100, 4) + "none"
+    elif isinstance(term, datetime):
+        return encode_term(((term.year, term.month, term.day),
+            (term.hour, term.minute, term.second)))
 
     raise ValueError("unsupported data type: %s" % type(term))
